pytest-aiofiles
===============

.. image:: https://img.shields.io/circleci/project/github/ptpb/pytest-aiofiles.svg
   :target: https://circleci.com/gh/ptpb/pytest-aiofiles

.. image:: https://img.shields.io/codecov/c/github/ptpb/pytest-aiofiles.svg
   :target: https://codecov.io/gh/ptpb/pytest-aiofiles

.. image:: https://img.shields.io/pypi/v/pytest-aiofiles.svg
   :target: https://pypi.org/project/pytest-aiofiles

pytest-aiofiles provides pytest fixtures for writing aiofiles tests
using pyfakefs, instead of real file IO.

Features
--------

- fake filesystem fixture attached to aiofiles
- automatic aiofiles monkey-patching

Documentation
-------------

http://pytest-aiofiles.readthedocs.io/

Source code
-----------

http://github.com/ptpb/pytest-aiofiles
